@@ -16,6 +16,7 @@ class DoubanClient(DoubanApi):
         self.scope = scope
         self.client = Client(key, secret,
                        site=self.API_HOST, authorize_url=self.AUTHORIZE_URL, token_url=self.TOKEN_URL)
+        self.access_token = None
 
     def __repr__(self):
         return '<DoubanClient OAuth2>'
@@ -25,15 +26,23 @@ class DoubanClient(DoubanApi):
         return self.client.auth_code.authorize_url(redirect_uri=self.redirect_uri, scope=self.scope)
 
     def auth_with_code(self, code):
-        self.client = self.client.auth_code.get_token(code, redirect_uri=self.redirect_uri)
+        self.access_token = self.client.auth_code.get_token(code, redirect_uri=self.redirect_uri)
 
     def auth_with_token(self, token):
-        self.client = AccessToken(self.client, token)
+        self.access_token = AccessToken(self.client, token)
 
     def auth_with_password(self, username, password, **opt):
-        self.client = self.client.password.get_token(username=username,
-                           password=password, redirect_uri=self.redirect_uri, **opt)
+        self.access_token = self.client.password.get_token(username=username,
+                                 password=password, redirect_uri=self.redirect_uri, **opt)
+
+    @property
+    def token_code(self):
+        return self.access_token and self.access_token.token
+
+    @property
+    def refresh_token_code(self):
+        return getattr(self.access_token, 'refresh_token', None)
 
     def refresh_token(self, refresh_token):
         access_token = AccessToken(self.client, token='', refresh_token=refresh_token)
-        self.client = access_token.refresh()
+        self.access_token = access_token.refresh()
